package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.YashanDatabaseServicesMapper;
import com.zyc.system.domain.YashanDatabaseServices;
import com.zyc.system.service.IYashanDatabaseServicesService;

/**
 * 崖山数据库服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class YashanDatabaseServicesServiceImpl implements IYashanDatabaseServicesService 
{
    @Autowired
    private YashanDatabaseServicesMapper yashanDatabaseServicesMapper;

    /**
     * 查询崖山数据库服务
     * 
     * @param id 崖山数据库服务主键
     * @return 崖山数据库服务
     */
    @Override
    public YashanDatabaseServices selectYashanDatabaseServicesById(Integer id)
    {
        return yashanDatabaseServicesMapper.selectYashanDatabaseServicesById(id);
    }

    /**
     * 查询崖山数据库服务列表
     * 
     * @param yashanDatabaseServices 崖山数据库服务
     * @return 崖山数据库服务
     */
    @Override
    public List<YashanDatabaseServices> selectYashanDatabaseServicesList(YashanDatabaseServices yashanDatabaseServices)
    {
        return yashanDatabaseServicesMapper.selectYashanDatabaseServicesList(yashanDatabaseServices);
    }

    /**
     * 新增崖山数据库服务
     * 
     * @param yashanDatabaseServices 崖山数据库服务
     * @return 结果
     */
    @Override
    public int insertYashanDatabaseServices(YashanDatabaseServices yashanDatabaseServices)
    {
        return yashanDatabaseServicesMapper.insertYashanDatabaseServices(yashanDatabaseServices);
    }

    /**
     * 修改崖山数据库服务
     * 
     * @param yashanDatabaseServices 崖山数据库服务
     * @return 结果
     */
    @Override
    public int updateYashanDatabaseServices(YashanDatabaseServices yashanDatabaseServices)
    {
        return yashanDatabaseServicesMapper.updateYashanDatabaseServices(yashanDatabaseServices);
    }

    /**
     * 批量删除崖山数据库服务
     * 
     * @param ids 需要删除的崖山数据库服务主键
     * @return 结果
     */
    @Override
    public int deleteYashanDatabaseServicesByIds(Integer[] ids)
    {
        return yashanDatabaseServicesMapper.deleteYashanDatabaseServicesByIds(ids);
    }

    /**
     * 删除崖山数据库服务信息
     * 
     * @param id 崖山数据库服务主键
     * @return 结果
     */
    @Override
    public int deleteYashanDatabaseServicesById(Integer id)
    {
        return yashanDatabaseServicesMapper.deleteYashanDatabaseServicesById(id);
    }
}
