package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.YashanDatabaseServices;
import com.zyc.system.service.IYashanDatabaseServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 崖山数据库服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/YashanDatabaseServicesController")
public class YashanDatabaseServicesController extends BaseController
{
    @Autowired
    private IYashanDatabaseServicesService yashanDatabaseServicesService;

    /**
     * 查询崖山数据库服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(YashanDatabaseServices yashanDatabaseServices)
    {
        startPage();
        List<YashanDatabaseServices> list = yashanDatabaseServicesService.selectYashanDatabaseServicesList(yashanDatabaseServices);
        return getDataTable(list);
    }

    /**
     * 导出崖山数据库服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "崖山数据库服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, YashanDatabaseServices yashanDatabaseServices)
    {
        List<YashanDatabaseServices> list = yashanDatabaseServicesService.selectYashanDatabaseServicesList(yashanDatabaseServices);
        ExcelUtil<YashanDatabaseServices> util = new ExcelUtil<YashanDatabaseServices>(YashanDatabaseServices.class);
        util.exportExcel(response, list, "崖山数据库服务数据");
    }

    /**
     * 获取崖山数据库服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(yashanDatabaseServicesService.selectYashanDatabaseServicesById(id));
    }

    /**
     * 新增崖山数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "崖山数据库服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody YashanDatabaseServices yashanDatabaseServices)
    {
        return toAjax(yashanDatabaseServicesService.insertYashanDatabaseServices(yashanDatabaseServices));
    }

    /**
     * 修改崖山数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "崖山数据库服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody YashanDatabaseServices yashanDatabaseServices)
    {
        return toAjax(yashanDatabaseServicesService.updateYashanDatabaseServices(yashanDatabaseServices));
    }

    /**
     * 删除崖山数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "崖山数据库服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(yashanDatabaseServicesService.deleteYashanDatabaseServicesByIds(ids));
    }
}
